variationCount property
The number of variations associated with the emoji returned from the v2/emoji endpoint
Implementation
final int? variationCount;
The number of variations associated with the emoji returned from the v2/emoji endpoint
final int? variationCount;