GifData class

The GifData object contains various data points for a single GIF.

Implementers

Constructors

GifData({required GifType type, required String id, required String slug, required String url, required String bitlyUrl, required String embedUrl, required String username, required String source, required Rating rating, required UserData? user, required String sourceTld, required String sourcePostUrl, required DateTime? updateDatetime, required DateTime? createDatetime, required DateTime importDatetime, required DateTime trendingDatetime, required ImageData images, required String title, required String? altText, String? contentUrl, bool isSticker = false, String? analyticsResponsePayload, required AnalyticsData? analytics})
GifData.fromJson(Map<String, dynamic> json)

Properties

altText String?
Alt text enables assistive programs to read descriptions of GIFs.
final
analytics → AnalyticsData?
Most of our endpoints return an Analytics Object. The Analytics Object provides URLs so you can register actions, such as when a user views, clicks, or sends a GIF.
final
analyticsResponsePayload String?
Most of our endpoints return an Analytics Object. The Analytics Object provides URLs so you can register actions, such as when a user views, clicks, or sends a GIF.
final
bitlyUri Uri
The unique bit.ly URL for this GIF
no setter
bitlyUrl String
The unique bit.ly URL for this GIF
final
contentUri Uri?
Currently unused
no setter
contentUrl String?
Currently unused
final
createDatetime DateTime?
The date this GIF was added to the GIPHY database.
final
embedUri Uri
A URL used for embedding this GIF
no setter
embedUrl String
A URL used for embedding this GIF
final
hashCode int
The hash code for this object.
no setterinherited
id String
This GIF's unique ID
final
images → ImageData
An object containing data for various available formats and sizes of this GIF.
final
importDatetime DateTime
The creation or upload date from this GIF's source.
final
isSticker bool
Whether this GIF is a sticker
final
rating Rating
The MPAA-style rating for this content. Examples include Y, G, PG, PG-13 and R
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String
The unique slug used in this GIF's URL
final
source String
The page on which this GIF was found
final
sourcePostUri Uri
The URL of the webpage on which this GIF was found.
no setter
sourcePostUrl String
The URL of the webpage on which this GIF was found.
final
sourceTld String
The top level domain of the source URL.
final
title String
The title that appears on giphy.com for this GIF.
final
trendingDatetime DateTime
The date on which this gif was marked trending, if applicable.
final
type GifType
By default, this is almost always GIF.
final
updateDatetime DateTime?
The date on which this GIF was last updated.
final
uri Uri
The unique URL for this GIF
no setter
url String
The unique URL for this GIF
final
user → UserData?
An object containing data about the user associated with this GIF, if applicable.
final
username String
The username this GIF is attached to, if applicable
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited