user property
UserData?
user
final
An object containing data about the user associated with this GIF, if applicable.
Implementation
final UserData? user;
An object containing data about the user associated with this GIF, if applicable.
final UserData? user;