GiphyLanguage enum

Giphy supported language

Inheritance
Available extensions

Values

en → const GiphyLanguage

English

es → const GiphyLanguage

Spanish

pt → const GiphyLanguage

Portuguese

id → const GiphyLanguage

Indonesian

fr → const GiphyLanguage

French

ar → const GiphyLanguage

Arabic

tr → const GiphyLanguage

Turkish

th → const GiphyLanguage

Thai

vi → const GiphyLanguage

Vietnamese

de → const GiphyLanguage

German

it → const GiphyLanguage

Italian

ja → const GiphyLanguage

Japanese

zhCN → const GiphyLanguage

Chinese Simplified

zhTW → const GiphyLanguage

Chinese Traditional

ru → const GiphyLanguage

Russian

ko → const GiphyLanguage

Korean

pl → const GiphyLanguage

Polish

nl → const GiphyLanguage

Dutch

ro → const GiphyLanguage

Romanian

hu → const GiphyLanguage

Hungarian

sv → const GiphyLanguage

Swedish

cs → const GiphyLanguage

Czech

hi → const GiphyLanguage

Hindi

bn → const GiphyLanguage

Bengali

da → const GiphyLanguage

Danish

fa → const GiphyLanguage

Farsi

tl → const GiphyLanguage

Filipino

fi → const GiphyLanguage

Finnish

he → const GiphyLanguage

Hebrew

ms → const GiphyLanguage

Malay

no → const GiphyLanguage

Norwegian

uk → const GiphyLanguage

Ukrainian

Properties

apiValue String
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GiphyLanguage>
A constant List of the values in this enum, in order of their declaration.