Rating enum

GIFs are for everyone, and GIPHY is committed to making sure that its GIF search is a positive experience for everyone. We take content safety extremely seriously. Our GIF and Sticker library is thoroughly moderated and organized by rating in order to give GIPHY users the safest possible search experience. We do not hesitate to remove content that falls outside of our Community Guidelines. More informations on Giphy documentations https://developers.giphy.com/docs/optional-settings/#rating

Inheritance
Available extensions

Values

y → const Rating
g → const Rating

Contains images that are broadly accepted as appropriate and commonly witnessed by people in a public environment.

pg → const Rating

Contains images that are commonly witnessed in a public environment, but not as broadly accepted as appropriate.

pg13 → const Rating

Contains images that are typically not seen unless sought out, but still commonly witnessed.

r → const Rating

Contains images that are typically not seen unless sought out and could be considered alarming if witnessed.

Properties

apiValue String
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String rating) Rating

Constants

values → const List<Rating>
A constant List of the values in this enum, in order of their declaration.