SuccessTrendingSearchResponseModel class

Response model for Giphy API

Only for trending search

Constructors

SuccessTrendingSearchResponseModel({required List<String> data, required MetaData meta})
SuccessTrendingSearchResponseModel.fromJson(Map<String, dynamic> json)
factory

Properties

data List<String>
List of String
final
hashCode int
The hash code for this object.
no setterinherited
meta → MetaData
Meta data
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited