GiphyResult class

A class that represents a Giphy result.

The Giphy result contains the title, URL, preview URL, image URL, and Giphy URL.

Constructors

GiphyResult({required String title, required String url, required String previewUrl, required String? imageUrl, required String giphyUrl})

Properties

giphyUrl String
The Giphy URL of the Giphy result.
final
hashCode int
The hash code for this object.
no setterinherited
imageUrl String?
The image URL of the Giphy result.
final
previewUrl String
The preview URL of the Giphy result.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
The title of the Giphy result.
final
url String
The URL of the Giphy result.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited