GiphyThemeMode enum

GiphyThemeMode enum is used to decide which theme mode to use

system: Use system theme mode light: Use light theme mode dark: Use dark theme mode app: Use app theme mode

Inheritance
Available extensions

Values

system → const GiphyThemeMode
light → const GiphyThemeMode
dark → const GiphyThemeMode
app → const GiphyThemeMode

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toThemeMode(BuildContext context) ThemeMode

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GiphyThemeMode>
A constant List of the values in this enum, in order of their declaration.