GiphyUIConfig class

Giphy UI Config

apiKey: Giphy API Key themeMode: GiphyThemeMode lightTheme: ThemeData darkTheme: ThemeData rating: Rating language: GiphyLanguage bundle: Bundle show: List<GiphyShow> functionsGif: List<GiphyFunction> functionsSticker: List<GiphyFunction> useSafeArea: bool useAlertDialog: bool width: double previewQuality: PreviewQuality

Constructors

GiphyUIConfig({required String apiKey, GiphyThemeMode themeMode = GiphyThemeMode.app, ThemeData? lightTheme, ThemeData? darkTheme, Rating? rating, GiphyLanguage language = GiphyLanguage.en, Bundle? bundle, bool useSafeArea = false, bool useAlertDialog = false, double? width, PreviewQuality previewQuality = PreviewQuality.preview, List<GiphyShow> show = const [GiphyShow.gif, GiphyShow.sticker, GiphyShow.emoji], List<GiphyFunction> functionsGif = const [GiphyFunction.favorites, GiphyFunction.search, GiphyFunction.trending, GiphyFunction.translate], List<GiphyFunction> functionsSticker = const [GiphyFunction.favorites, GiphyFunction.search, GiphyFunction.trending, GiphyFunction.translate]})

Properties

apiKey String
Giphy API Key
final
bundle Bundle?
Bundle for Giphy results
final
darkTheme ThemeData?
Dark Theme for the Giphy UI
final
functionsGif List<GiphyFunction>
Giphy functionnalities for Gif
final
functionsSticker List<GiphyFunction>
Giphy functionnalities for Sticker
final
hashCode int
The hash code for this object.
no setterinherited
language GiphyLanguage
Language for Giphy results
final
lightTheme ThemeData?
Light Theme for the Giphy UI
final
previewQuality PreviewQuality
Preview quality Default is small to load faster the preview
final
rating Rating?
Rating for Giphy results
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
show List<GiphyShow>
Show Giphy functionnalities (Gif, Sticker, Emoji)
final
themeMode GiphyThemeMode
Theme Mode for the Giphy UI
final
useAlertDialog bool
Use alert dialog instead of bottom sheet
final
useSafeArea bool
Use safe area
final
width double?
Width of the Giphy UI If null, then the screen width will be used
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited