PreviewQuality enum

PreviewQuality enum is used to decide which quality to show for the preview

original: Show original quality (slow to load) large: Show large quality (8mb max size) medium: Show medium quality (5mb max size) small: Show small quality (200kb max size)

Inheritance
Available extensions

Values

original → const PreviewQuality
large → const PreviewQuality
medium → const PreviewQuality
small → const PreviewQuality
preview → const PreviewQuality

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PreviewQuality>
A constant List of the values in this enum, in order of their declaration.