CategoriesData class
Categories Data
This object contains various data points for a single category.
Constructors
-
CategoriesData({required String name, required String nameEncoded, required List<
SubCategories> subCategories, required GifData gif}) -
CategoriesData.fromJson(Map<
String, dynamic> json) -
factory
Properties
- gif → GifData
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Category name
final
- nameEncoded → String
-
Encoded category name
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subCategories
→ List<
SubCategories> -
List of subcategories
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited