EmojiData class
Emoji Data
This object contains various data points for a single emoji.
Constructors
- EmojiData({required GifType type, required String id, required String slug, required String url, required String bitlyUrl, required String embedUrl, required String username, required String source, required Rating rating, required UserData? user, required String sourceTld, required String sourcePostUrl, required DateTime? updateDatetime, required DateTime? createDatetime, required DateTime importDatetime, required DateTime trendingDatetime, required ImageData images, required String title, required String? altText, required String? contentUrl, required bool isSticker, required String? analyticsResponsePayload, required AnalyticsData? analytics, required int emojiGroupId, required String variation, required int? variationCount})
-
EmojiData.fromJson(Map<
String, dynamic> json)
Properties
- altText → String?
-
Alt text enables assistive programs to read descriptions of GIFs.
finalinherited
- analytics → AnalyticsData?
-
Most of our endpoints return an Analytics Object. The Analytics Object provides URLs so you can register actions, such as when a user views, clicks, or sends a GIF.
finalinherited
- analyticsResponsePayload → String?
-
Most of our endpoints return an Analytics Object. The Analytics Object provides URLs so you can register actions, such as when a user views, clicks, or sends a GIF.
finalinherited
- bitlyUri → Uri
-
The unique bit.ly URL for this GIF
no setterinherited
- bitlyUrl → String
-
The unique bit.ly URL for this GIF
finalinherited
- contentUri → Uri?
-
Currently unused
no setterinherited
- contentUrl → String?
-
Currently unused
finalinherited
- createDatetime → DateTime?
-
The date this GIF was added to the GIPHY database.
finalinherited
- embedUri → Uri
-
A URL used for embedding this GIF
no setterinherited
- embedUrl → String
-
A URL used for embedding this GIF
finalinherited
- emojiGroupId → int
-
The ID of the emoji group
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
This GIF's unique ID
finalinherited
- images → ImageData
-
An object containing data for various available formats and sizes of this GIF.
finalinherited
- importDatetime → DateTime
-
The creation or upload date from this GIF's source.
finalinherited
- isSticker → bool
-
Whether this GIF is a sticker
finalinherited
- rating → Rating
-
The MPAA-style rating for this content. Examples include Y, G, PG, PG-13 and R
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slug → String
-
The unique slug used in this GIF's URL
finalinherited
- source → String
-
The page on which this GIF was found
finalinherited
- sourcePostUri → Uri
-
The URL of the webpage on which this GIF was found.
no setterinherited
- sourcePostUrl → String
-
The URL of the webpage on which this GIF was found.
finalinherited
- sourceTld → String
-
The top level domain of the source URL.
finalinherited
- title → String
-
The title that appears on giphy.com for this GIF.
finalinherited
- trendingDatetime → DateTime
-
The date on which this gif was marked trending, if applicable.
finalinherited
- type → GifType
-
By default, this is almost always GIF.
finalinherited
- updateDatetime → DateTime?
-
The date on which this GIF was last updated.
finalinherited
- uri → Uri
-
The unique URL for this GIF
no setterinherited
- url → String
-
The unique URL for this GIF
finalinherited
- user → UserData?
-
An object containing data about the user associated with this GIF, if applicable.
finalinherited
- username → String
-
The username this GIF is attached to, if applicable
finalinherited
- variation → String
-
Name of the emoji variation
final
- variationCount → int?
-
The number of variations associated with the emoji returned from the v2/emoji endpoint
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited