SuccessCategoriesResponseModel class
Response model for Giphy API
Only for Categories
Constructors
-
SuccessCategoriesResponseModel({required List<
CategoriesData> data, required PaginationData pagination, required MetaData meta}) -
SuccessCategoriesResponseModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
data
→ List<
CategoriesData> -
List of CategoriesData
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → MetaData
-
Meta data
final
- pagination → PaginationData
-
Pagination data
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited