GiphyLocale enum
Giphy Locale
This enum represents the supported locales for the Giphy picker.
Values
- fr → const GiphyLocale
-
French
- en → const GiphyLocale
-
English
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- locale → Locale
-
Get the locale from the GiphyLocale
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromContext(
BuildContext context) → GiphyLocale - Get the GiphyLocale from the context
Constants
-
values
→ const List<
GiphyLocale> - A constant List of the values in this enum, in order of their declaration.